<?php

// DIC configuration

$container = $app->getContainer();

// -----------------------------------------------------------------------------
// Service providers
// -----------------------------------------------------------------------------
// Database
$container['capsule'] = function ($c) {
    $capsule = new Illuminate\Database\Capsule\Manager;
    $capsule->addConnection($c['settings']['db']);
    return $capsule;
};




// Twig
$container['view'] = function ($c) {
    $settings = $c->get('settings');
    $view = new Slim\Views\Twig($settings['view']['template_path'], $settings['view']['twig']);

    // Add extensions
    $view->addExtension(new Slim\Views\TwigExtension($c->get('router'), $c->get('request')->getUri()));
    $view->addExtension(new Twig_Extension_Debug());

    return $view;
};

// Flash messages
$container['flash'] = function ($c) {
    return new Slim\Flash\Messages;
};

// -----------------------------------------------------------------------------
// Service factories
// -----------------------------------------------------------------------------
// monolog
$container['logger'] = function ($c) {
    $settings = $c->get('settings');
    $logger = new Monolog\Logger($settings['logger']['name']);
    $logger->pushProcessor(new Monolog\Processor\UidProcessor());
    $logger->pushHandler(new Monolog\Handler\StreamHandler($settings['logger']['path'], Monolog\Logger::DEBUG));
    return $logger;
};

//SwiftMailer
$container['mailer'] = function ($c) {
    $settings = $c->get('settings');

    $transport = Swift_SmtpTransport::newInstance($settings['mail']['smtp_server'], $settings['mail']['smtp_port'], $settings['mail']['encryption'])
            ->setUsername($settings['mail']['username'])
            ->setPassword($settings['mail']['password']);
    $mailer = Swift_Mailer::newInstance($transport);
    return $mailer;
};



// -----------------------------------------------------------------------------
// Action factories
// ----------------------------------------------------------------------------- 
$container[App\Action\CommonAction::class] = function ($c) {
    return new App\Action\CommonAction($c->get('view'), $c->get('logger'), $c->get('mailer'));
};
$container[App\Action\MasterAction::class] = function ($c) {
    return new App\Action\MasterAction($c->get('view'), $c->get('logger'), $c->get('mailer'));
};


